# moeda-br

Description.
O pacote moeda-br é utilizado para converter valores em moeda brasileira:
    conversor:
        conversor-de-moeda

## Install

Use o package manager [pip](https://pip.pypa.io/en/stable) para instalar o pacote moeda-br

'''bash
pip install moeda-br
'''

## Usage

'''python
from moeda-br import conversor
conversor.conversor-de-moeda(valor)
'''

## Author

Lindon Johnson L Macedo
